@@ -27,8 +27,8 @@ use     strict;
 #       Common lpOD/Perl parameters and utility functions
 #-----------------------------------------------------------------------------
 package ODF::lpOD::Common;
-our	$VERSION	        = '0.100';
-use constant PACKAGE_DATE => '2010-06-25T14:17:07';
+our	$VERSION	        = '0.101';
+use constant PACKAGE_DATE => '2010-06-26T19:12:50';
 #-----------------------------------------------------------------------------
 use Scalar::Util;
 use Encode;
@@ -49,6 +49,7 @@ our @EXPORT     = qw
         odf_create_element odf_create_paragraph odf_create_heading
         odf_create_section
         odf_create_table odf_create_column odf_create_row odf_create_cell
+        odf_create_column_group odf_create_row_group
         odf_create_field
 
         odf_document odf_container
@@ -57,7 +58,7 @@ our @EXPORT     = qw
         odf_element odf_text_element odf_bibliography_mark
         odf_paragraph odf_heading odf_draw_page odf_section
         odf_list odf_table odf_column odf_row odf_cell odf_field
-        odf_table_element
+        odf_matrix odf_column_group odf_row_group odf_table_element
 
         TRUE FALSE PRETTY
         is_true is_false is_odf_datatype odf_boolean process_options
@@ -101,6 +102,9 @@ use constant
         odf_field               => 'ODF::lpOD::Field',
         odf_table               => 'ODF::lpOD::Table',
         odf_table_element       => 'ODF::lpOD::TableElement',
+        odf_matrix              => 'ODF::lpOD::Matrix',
+        odf_column_group        => 'ODF::lpOD::ColumnGroup',
+        odf_row_group           => 'ODF::lpOD::RowGroup',
         odf_column              => 'ODF::lpOD::Column',
         odf_row                 => 'ODF::lpOD::Row',
         odf_cell                => 'ODF::lpOD::Cell',
@@ -195,6 +199,9 @@ BEGIN   {
         *odf_create_heading     = *ODF::lpOD::Heading::create;
         *odf_create_field       = *ODF::lpOD::Field::create;
         *odf_create_table       = *ODF::lpOD::Table::create;
+        *odf_create_column_group                =
+                *ODF::lpOD::RowGroup::create;
+        *odf_create_row_group   = *ODF::lpOD::Row::create;
         *odf_create_column      = *ODF::lpOD::Column::create;
         *odf_create_row         = *ODF::lpOD::Row::create;
         *odf_create_cell        = *ODF::lpOD::Cell::create;
@@ -286,7 +293,6 @@ sub     check_odf_value
         {
         my $value       = shift;
         my $type        = shift;
-
         given ($type)
                 {
                 when (undef)
